@@ -1,12 +1,15 @@
 package Convert::Recode;
 
-# $Id: Recode.pm,v 1.3 1997/09/19 09:09:00 aas Exp $
+# $Id: Recode.pm,v 1.6 2003/12/18 10:24:32 gisle Exp $
 
-use Carp;
 use strict;
 
 use vars qw($VERSION $DEBUG);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "1.04";
+
+use Carp qw(croak);
+use File::Spec;
+my $devnull = File::Spec->devnull;
 
 
 sub import
@@ -21,7 +24,7 @@ sub import
 	}
 	local(*RECODE, $_);
 	my $strict = $1 ? "s" : "";  # strict mode flag
-	open(RECODE, "recode -${strict}h $2:$3 2>/dev/null|") or die;
+	open(RECODE, "recode -${strict}h $2..$3 2>$devnull|") or die;
 	my @codes;
 	while (<RECODE>) {
 	    push(@codes, /(\d+|\"[^\"]*\"),/g);
@@ -85,23 +88,26 @@ Convert::Recode - make mapping functions between character sets
 
 The Convert::Recode module can provide mapping functions between
 character sets on demand.  It depends on GNU recode to provide the raw
-mapping data, i.e. GNU recode must be installed first.  The names of
-the mapping functions are found by taking the name of the two charsets
-and then joining them with the string "_to_".  If you want to convert
-between the "mac" and the "latin1" charsets, then you just import the
+mapping data, i.e. GNU recode must be installed first.  The name of
+the mapping function is constructed by taking the names of the two charsets
+and joining them with the string "_to_".  For example, if you want to convert
+between the "mac" and the "latin1" charsets, just import the
 mac_to_latin1() function.
 
-If you prefix the function name with "strict_" then characters that
-can not be mapped are removed during transformation.  For instance the
-strict_mac_to_latin1() function will convert to a string to latin1 and
-remove all mac characters that have not corresponding latin1
+If you prefix the function name with "strict_", any characters that
+cannot be mapped are removed during transformation.  For instance, the
+strict_mac_to_latin1() function converts a string to latin1 and
+removes all mac characters that do not have a corresponding latin1
 character.
 
-Running the command C<recode -l> should give you the list of character
-sets available.
+Running the command C<recode -l> should give you the list of available
+character sets.
 
-=head1 AUTHOR
+=head1 COPYRIGHT
 
- 1997 Gisle Aas.
+ 1997,2003 Gisle Aas.  All rights reserved.
+
+This library is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
 
 =cut
